==> hoteldruid-mod-ca_2.1.1-1.tar.gz: ca/modifica_var_contr.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Variabili personalizzate dei documenti":  $messaggio = "Variables personalitzades dels documents"; break;
case "Variabili personalizzate":  		$messaggio = "Variables personalitzades"; break;
case "Elimina":  				$messaggio = "Eliminar"; break;
case "Aggiungi":  				$messaggio = "Afegir"; break;
case "se":  					$messaggio = "si"; break;
case "è uguale a":  				$messaggio = "és igual a"; break;
case "è diverso da":  				$messaggio = "és diferent de"; break;
case "allora porre":  				$messaggio = "llavors posar"; break;
case "uguale a":  				$messaggio = "igual a"; break;
case "Nuova variabile personalizzata inserita":	$messaggio = "Nova variable personalitzada inserida"; break;
case "I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "Les dades inserides són <div style=\"display: inline; color: red;\">errònies</div>"; break;
case "Variabile personalizzata eliminata":  	$messaggio = "Variable personalitzada eliminada"; break;
case "Nuova condizione inserita":  		$messaggio = "Nova condició inserida"; break;
case "Condizione eliminata":  			$messaggio = "Condició eliminada"; break;
case "porre":  					$messaggio = "posar"; break;
case "sostituendo":  				$messaggio = "substituïnt"; break;
case "con":  					$messaggio = "amb"; break;
case "arrotondato a":  				$messaggio = "arrodonit a"; break;
case "e":  					$messaggio = "i"; break;
case "o":  					$messaggio = "o"; break;
case "concatenato con":  			$messaggio = "concatenat amb"; break;
case "allora":  				$messaggio = "llavors"; break;
case "uguaglia":  				$messaggio = "igualar"; break;
case "concatena":  				$messaggio = "concatenar"; break;
case "troncare":  				$messaggio = "truncar"; break;
case "dopo":  					$messaggio = "després de"; break;
case "caratteri":  				$messaggio = "caràcters"; break;
case "se mancanti riempire con":  		$messaggio = "si falta omplir con"; break;
case "la parte":  				$messaggio = "la part"; break;
case "finale":  				$messaggio = "final"; break;
case "iniziale":  				$messaggio = "inicial"; break;
case "riempiendo i mancanti con":  		$messaggio = "omplint els que faltin amb"; break;
case "all'inizio":  				$messaggio = "al començament"; break;
case "alla fine":  				$messaggio = "al final"; break;
case "Array personalizzati":  			$messaggio = "Matrius personalitzades"; break;
case "Array della variabile":  			$messaggio = "Matriu de la variable"; break;
case "Valori iniziali da assegnare all'array":	$messaggio = "Valors inicials a assignar a la matriu"; break;
case "Nessun valore predefinito":  		$messaggio = "Cap valor predefinit"; break;
case "valori progressivi tra le date selezionate":	$messaggio = "valors correlatius entre les dates seleccionades"; break;
case "una lista di valori predefiniti":  	$messaggio = "una llista de valors predefinits"; break;
case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "a les repeticions són considerades només les reserves a la data evaluada"; break;
case "<b>Condizioni</b> applicate":  		$messaggio = "<b>Condicions</b> aplicades"; break;
case "a tutti i documenti":  			$messaggio = "a tots els documents"; break;
case "al documento":  				$messaggio = "al document"; break;
case "Modifica le condizioni applicate":  	$messaggio = "Modificar les condicions aplicades"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "Array personalizzato eliminato":  	$messaggio = "Matriu personalitzada eliminada"; break;
case "Nuovo array personalizzato inserito":  	$messaggio = "Nova matriu personalitzada inserida"; break;
case "azzera l'array":  			$messaggio = "posa la matriu a zero"; break;
case "non processare le condizioni successive":	$messaggio = "no processar les condicions següents"; break;
case "è maggiore di":  				$messaggio = "es més gran que"; break;
case "è minore di":  				$messaggio = "es menor que"; break;
case "solo al documento":  			$messaggio = "només al document"; break;
case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "només al començament de les repeticions de les reserves"; break;
case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "a totes les repeticions de les reserves"; break;
case "Modifica il documento":  			$messaggio = "Modificar el document"; break;
case "nuova condizione":  			$messaggio = "nova condició"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "solo all'inizio del documento":  		$messaggio = "només al principi del document"; break;
case "sempre":  				$messaggio = "sempre"; break;
case "azione":  				$messaggio = "acció"; break;
case "aggiungi un altro &quot;se&quot;":  	$messaggio = "afegir un altre &quot;si&quot;"; break;
case "azzera l'array":  			$messaggio = "posar la matriu a zero"; break;
case "assegna all'array":  			$messaggio = "assignar a la matriu"; break;
case "aggiungi la nuova condizione":  		$messaggio = "afegir una nova condició"; break;
case "i valori":  				$messaggio = "els valors"; break;
case "fino alla fine":  			$messaggio = "fins el final"; break;
case "fino al prossimo &quot;riprendi&quot;":  	$messaggio = "fins el proper &quot;reanudar&quot;"; break;
case "riprendi a processare le condizioni successive":	$messaggio = "reanudar el processament de les condicions següents"; break;
case "se precedentemente interrotte":  		$messaggio = "si habien estat interrompudes"; break;
case "modifica la condizione":  		$messaggio = "modificar la condició"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "condizione modificata":  			$messaggio = "condició modificada"; break;
case "annulla":  				$messaggio = "anul·lar"; break;
case "Utilizza sempre":				$messaggio = "Emprar sempre"; break;
case "Importa ora":				$messaggio = "Importar ara"; break;
case "variabili e condizioni del documento":	$messaggio = "variables i condicions del document"; break;
case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "les variables i condicions actuals s'esborraran"; break;
case "Visualizza le condizioni del documento":	$messaggio = "Veure les condicions del document"; break;
case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "il giorno":  				$messaggio = "the day"; break;
case "il mese":  				$messaggio = "the month"; break;
case "l'anno":  				$messaggio = "the year"; break;
case "il giorno della settimana":  		$messaggio = "the day of the week"; break;
case "della data":  				$messaggio = "from date"; break;
case "contiene":  				$messaggio = "contains"; break;
case "maiusc./minusc.":  			$messaggio = "case sensitive"; break;
case "la data":  				$messaggio = "the date"; break;
case "formato ISO":  				$messaggio = "ISO format"; break;
case "formato corrente":  			$messaggio = "current format"; break;
case "giorni":  				$messaggio = "days"; break;
case "mesi":  					$messaggio = "months"; break;
case "anni":  					$messaggio = "years"; break;
case "i valori dell'array":  			$messaggio = "the values from array"; break;
case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ca_2.1.3-1.tar.gz: ca/modifica_var_contr.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Variabili personalizzate dei documenti":  $messaggio = "Variables personalitzades dels documents"; break;
case "Variabili personalizzate":  		$messaggio = "Variables personalitzades"; break;
case "Elimina":  				$messaggio = "Eliminar"; break;
case "Aggiungi":  				$messaggio = "Afegir"; break;
case "se":  					$messaggio = "si"; break;
case "è uguale a":  				$messaggio = "és igual a"; break;
case "è diverso da":  				$messaggio = "és diferent de"; break;
case "allora porre":  				$messaggio = "llavors posar"; break;
case "uguale a":  				$messaggio = "igual a"; break;
case "Nuova variabile personalizzata inserita":	$messaggio = "Nova variable personalitzada inserida"; break;
case "I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "Les dades inserides són <div style=\"display: inline; color: red;\">errònies</div>"; break;
case "Variabile personalizzata eliminata":  	$messaggio = "Variable personalitzada eliminada"; break;
case "Nuova condizione inserita":  		$messaggio = "Nova condició inserida"; break;
case "Condizione eliminata":  			$messaggio = "Condició eliminada"; break;
case "porre":  					$messaggio = "posar"; break;
case "sostituendo":  				$messaggio = "substituïnt"; break;
case "con":  					$messaggio = "amb"; break;
case "arrotondato a":  				$messaggio = "arrodonit a"; break;
case "e":  					$messaggio = "i"; break;
case "o":  					$messaggio = "o"; break;
case "concatenato con":  			$messaggio = "concatenat amb"; break;
case "allora":  				$messaggio = "llavors"; break;
case "uguaglia":  				$messaggio = "igualar"; break;
case "concatena":  				$messaggio = "concatenar"; break;
case "troncare":  				$messaggio = "truncar"; break;
case "dopo":  					$messaggio = "després de"; break;
case "caratteri":  				$messaggio = "caràcters"; break;
case "se mancanti riempire con":  		$messaggio = "si falta omplir con"; break;
case "la parte":  				$messaggio = "la part"; break;
case "finale":  				$messaggio = "final"; break;
case "iniziale":  				$messaggio = "inicial"; break;
case "riempiendo i mancanti con":  		$messaggio = "omplint els que faltin amb"; break;
case "all'inizio":  				$messaggio = "al començament"; break;
case "alla fine":  				$messaggio = "al final"; break;
case "Array personalizzati":  			$messaggio = "Matrius personalitzades"; break;
case "Array della variabile":  			$messaggio = "Matriu de la variable"; break;
case "Valori iniziali da assegnare all'array":	$messaggio = "Valors inicials a assignar a la matriu"; break;
case "Nessun valore predefinito":  		$messaggio = "Cap valor predefinit"; break;
case "valori progressivi tra le date selezionate":	$messaggio = "valors correlatius entre les dates seleccionades"; break;
case "una lista di valori predefiniti":  	$messaggio = "una llista de valors predefinits"; break;
case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "a les repeticions són considerades només les reserves a la data evaluada"; break;
case "<b>Condizioni</b> applicate":  		$messaggio = "<b>Condicions</b> aplicades"; break;
case "a tutti i documenti":  			$messaggio = "a tots els documents"; break;
case "al documento":  				$messaggio = "al document"; break;
case "Modifica le condizioni applicate":  	$messaggio = "Modificar les condicions aplicades"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "Array personalizzato eliminato":  	$messaggio = "Matriu personalitzada eliminada"; break;
case "Nuovo array personalizzato inserito":  	$messaggio = "Nova matriu personalitzada inserida"; break;
case "azzera l'array":  			$messaggio = "posa la matriu a zero"; break;
case "non processare le condizioni successive":	$messaggio = "no processar les condicions següents"; break;
case "è maggiore di":  				$messaggio = "es més gran que"; break;
case "è minore di":  				$messaggio = "es menor que"; break;
case "solo al documento":  			$messaggio = "només al document"; break;
case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "només al començament de les repeticions de les reserves"; break;
case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "a totes les repeticions de les reserves"; break;
case "Modifica il documento":  			$messaggio = "Modificar el document"; break;
case "nuova condizione":  			$messaggio = "nova condició"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "solo all'inizio del documento":  		$messaggio = "només al principi del document"; break;
case "sempre":  				$messaggio = "sempre"; break;
case "azione":  				$messaggio = "acció"; break;
case "aggiungi un altro &quot;se&quot;":  	$messaggio = "afegir un altre &quot;si&quot;"; break;
case "azzera l'array":  			$messaggio = "posar la matriu a zero"; break;
case "assegna all'array":  			$messaggio = "assignar a la matriu"; break;
case "aggiungi la nuova condizione":  		$messaggio = "afegir una nova condició"; break;
case "i valori":  				$messaggio = "els valors"; break;
case "fino alla fine":  			$messaggio = "fins el final"; break;
case "fino al prossimo &quot;riprendi&quot;":  	$messaggio = "fins el proper &quot;reanudar&quot;"; break;
case "riprendi a processare le condizioni successive":	$messaggio = "reanudar el processament de les condicions següents"; break;
case "se precedentemente interrotte":  		$messaggio = "si habien estat interrompudes"; break;
case "modifica la condizione":  		$messaggio = "modificar la condició"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "condizione modificata":  			$messaggio = "condició modificada"; break;
case "annulla":  				$messaggio = "anul·lar"; break;
case "Utilizza sempre":				$messaggio = "Emprar sempre"; break;
case "Importa ora":				$messaggio = "Importar ara"; break;
case "variabili e condizioni del documento":	$messaggio = "variables i condicions del document"; break;
case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "les variables i condicions actuals s'esborraran"; break;
case "Visualizza le condizioni del documento":	$messaggio = "Veure les condicions del document"; break;
case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
case "valori progressivi tra il primo arrivo e l'ultima partenza":	$messaggio = "progressive values between first arrival and last departure"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "il giorno":  				$messaggio = "the day"; break;
case "il mese":  				$messaggio = "the month"; break;
case "l'anno":  				$messaggio = "the year"; break;
case "il giorno della settimana":  		$messaggio = "the day of the week"; break;
case "della data":  				$messaggio = "from date"; break;
case "contiene":  				$messaggio = "contains"; break;
case "maiusc./minusc.":  			$messaggio = "case sensitive"; break;
case "la data":  				$messaggio = "the date"; break;
case "formato ISO":  				$messaggio = "ISO format"; break;
case "formato corrente":  			$messaggio = "current format"; break;
case "giorni":  				$messaggio = "days"; break;
case "mesi":  					$messaggio = "months"; break;
case "anni":  					$messaggio = "years"; break;
case "i valori dell'array":  			$messaggio = "the values from array"; break;
case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
case "uguale al numero di":  			$messaggio = "equal to the number of"; break;
case "numero di":  				$messaggio = "the number of"; break;
case "dalla data":  				$messaggio = "from date"; break;
case "alla data":  				$messaggio = "to date"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
